cis_config: CisRpcServer Class Reference

cis_config

Public Member Functions | List of all members
CisRpcServer Class Reference

C++ interface to cisRpc_t server-side functionality. The CisRpcServer class is a basic wrapper around the C cisRpc_t structure and associated server-side functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC server operations. More...

`#include <CisInterface.hpp>`

Inheritance diagram for CisRpcServer:

## Public Member Functions
| CisRpcServer (const char *name, const char *inFormat, const char *outFormat)
| Constructor for CisRpcServer. More...
| ~CisRpcServer ()
| Destructor for CisRpcServer. See cis_free in CisInterface.h for details.
Public Member Functions inherited from CisRpc
| CisRpc (const char *name, const char *outFormat, const char *inFormat)
| Constructor for CisRpc. More...
| CisRpc (cisRpc_t x)
| Empty constructor for inheritance.
void | _destroy_pi ()
| Alias to allow freeing of underlying C struct at the class level.
| ~CisRpc ()
| Destructor for CisRpc. See cis_free in CisInterface.h for details.
cisRpc_t | pi ()
| Return the cisRpc_t structure. More...
int | send (const int nargs,...)
| Format and send a message to an RPC output queue. See rpcSend from CisInterface.h for details. More...
int | recv (const int nargs,...)
| Receive and parse a message from an RPC input queue. See rpcRecv from CisInterface.h for details. More...

## Detailed Description

C++ interface to cisRpc_t server-side functionality. The CisRpcServer class is a basic wrapper around the C cisRpc_t structure and associated server-side functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC server operations.

## Constructor & Destructor Documentation

## ◆ CisRpcServer()

CisRpcServer::CisRpcServer | ( | const char * | name,
|  | const char * | inFormat,
|  | const char * | outFormat
| ) |  |
| inline

Constructor for CisRpcServer.

Parameters

  [in] | name | constant character pointer name used for input and output queues.
  [in] | inFormat | character pointer to format that should be used for parsing input.
  [in] | outFormat | character pointer to format that should be used for formatting output.

The documentation for this class was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/interface/CisInterface.hpp